@@ -116,6 +116,11 @@ pub fn scan() -> Command {
             arg!(-n --"negate")
                 .help("Print non-satisfied rules only")
         )
+        .arg(
+            arg!(--"no-mmap")
+                .help("Don't use memory-mapped files")
+                .long_help(help::NO_MMAP_LONG_HELP)
+        )
         .arg(
             arg!(-o --"output-format" <FORMAT>)
                 .help("Output format for results")
@@ -250,6 +255,7 @@ pub fn exec_scan(args: &ArgMatches, config: &Config) -> anyhow::Result<()> {
     let disable_console_logs = args.get_flag("disable-console-logs");
     let scan_list = args.get_flag("scan-list");
     let recursive = args.get_one::<usize>("recursive");
+    let no_mmap = args.get_flag("no-mmap");
 
     let timeout =
         args.get_one::<u64>("timeout").map(|t| Duration::from_secs(*t));
@@ -386,6 +392,10 @@ pub fn exec_scan(args: &ArgMatches, config: &Config) -> anyhow::Result<()> {
                 }
             }
 
+            if no_mmap {
+                scanner.use_mmap(false);
+            }
+
             scanner
         },
         // File handler. Called for every file found while walking the path.
@@ -430,7 +440,7 @@ pub fn exec_scan(args: &ArgMatches, config: &Config) -> anyhow::Result<()> {
             let scan_results = scan_results?;
             let mut wanted_rules = match args.get_flag("negate") {
                 true => Box::new(scan_results.non_matching_rules())
-                    as Box<dyn ExactSizeIterator<Item = Rule>>,
+                    as Box<dyn ExactSizeIterator<Item=Rule>>,
                 false => Box::new(scan_results.matching_rules()),
             };
 
@@ -498,7 +508,7 @@ pub fn exec_scan(args: &ArgMatches, config: &Config) -> anyhow::Result<()> {
             Ok(())
         },
     )
-    .unwrap();
+        .unwrap();
 
     #[cfg(feature = "rules-profiling")]
     if profiling {
@@ -559,7 +569,7 @@ impl ScanState {
 // superconsole will not print any string that contains Unicode characters that
 // are spaces but are not the ASCII space character, so we replace them all.
 // See https://github.com/VirusTotal/yara-x/pull/163 for discussion.
-fn replace_whitespace(path: &Path) -> Cow<str> {
+fn replace_whitespace(path: &Path) -> Cow<'_, str> {
     let mut s = path.to_string_lossy();
     if s.chars().any(|c| c != ' ' && c.is_whitespace()) {
         let mut r = String::with_capacity(s.len());
@@ -596,7 +606,7 @@ impl Component for ScanState {
         let num_matching_files =
             self.num_matching_files.load(Ordering::Relaxed);
 
-        let matched = format!("{} file(s) matched.", num_matching_files);
+        let matched = format!("{num_matching_files} file(s) matched.");
 
         lines.push(Line::from_iter([
             Span::new_unstyled(scanned)?,
@@ -729,7 +739,7 @@ mod output_handler {
                     let more_bytes_message =
                         match match_data.len().saturating_sub(string_limit) {
                             0 => None,
-                            n => Some(format!(" ... {} more bytes", n)),
+                            n => Some(format!(" ... {n} more bytes")),
                         };
 
                     let string = match_data
@@ -849,16 +859,16 @@ mod output_handler {
                     for (pos, (m, v)) in metadata.with_position() {
                         match v {
                             MetaValue::Bool(v) => {
-                                msg.push_str(&format!("{}={}", m, v))
+                                msg.push_str(&format!("{m}={v}"))
                             }
                             MetaValue::Integer(v) => {
-                                msg.push_str(&format!("{}={}", m, v))
+                                msg.push_str(&format!("{m}={v}"))
                             }
                             MetaValue::Float(v) => {
-                                msg.push_str(&format!("{}={}", m, v))
+                                msg.push_str(&format!("{m}={v}"))
                             }
                             MetaValue::String(v) => {
-                                msg.push_str(&format!("{}=\"{}\"", m, v))
+                                msg.push_str(&format!("{m}=\"{v}\""))
                             }
                             MetaValue::Bytes(v) => msg.push_str(&format!(
                                 "{}=\"{}\"",
@@ -892,7 +902,7 @@ mod output_handler {
                             match m.xor_key() {
                                 Some(k) => {
                                     match_str.push_str(
-                                        format!(" xor({:#x},", k).as_str(),
+                                        format!(" xor({k:#x},").as_str(),
                                     );
                                     for b in &match_data
                                         [..min(match_data.len(), limit)]
@@ -929,7 +939,7 @@ mod output_handler {
                                     for (pos, b) in data.iter().with_position()
                                     {
                                         match_str.push_str(
-                                            format!("{:02x}", b).as_str(),
+                                            format!("{b:02x}").as_str(),
                                         );
                                         if !matches!(
                                             pos,
@@ -1066,7 +1076,7 @@ mod output_handler {
                     let more_bytes_message =
                         match match_data.len().saturating_sub(string_limit) {
                             0 => None,
-                            n => Some(format!(" ... {} more bytes", n)),
+                            n => Some(format!(" ... {n} more bytes")),
                         };
 
                     let string = match_data
