@@ -2,7 +2,10 @@ package yara_x
 
 import (
 	"bytes"
+	"fmt"
 	"testing"
+	"os"
+	"io/ioutil"
 
 	"github.com/stretchr/testify/assert"
 )
@@ -41,8 +44,7 @@ func TestBannedModules(t *testing.T) {
  --> line:1:1
   |
 1 | import "pe"
-  | ^^^^^^^^^^^ pe module was used here
-  |`
+  | ^^^^^^^^^^^ pe module was used here`
 	assert.EqualError(t, err, expected)
 }
 
@@ -54,11 +56,23 @@ func TestDisabledIncludes(t *testing.T) {
  --> line:1:1
   |
 1 | include "foo.yar"
-  | ^^^^^^^^^^^^^^^^^ includes are disabled for this compilation
-  |`
+  | ^^^^^^^^^^^^^^^^^ includes are disabled for this compilation`
 	assert.EqualError(t, err, expected)
 }
 
+func TestIncludes(t *testing.T) {
+    file, err := ioutil.TempFile("", "prefix")
+    assert.NoError(t, err)
+
+    defer os.Remove(file.Name())
+
+	_, err = Compile(
+		fmt.Sprintf(`include "%s"`, file.Name()),
+		IncludeDir(os.TempDir()))
+
+	assert.NoError(t, err)
+}
+
 func TestRelaxedReSyntax(t *testing.T) {
 	r, err := Compile(`
 		rule test { strings: $a = /\Release/ condition: $a }`,
@@ -161,8 +175,7 @@ func TestError(t *testing.T) {
  --> line:1:24
   |
 1 | rule test { condition: foo }
-  |                        ^^^ this identifier has not been declared
-  |`
+  |                        ^^^ this identifier has not been declared`
 	assert.EqualError(t, err, expected)
 }
 
@@ -174,16 +187,14 @@ func TestCompilerFeatures(t *testing.T) {
  --> line:1:57
   |
 1 | import "test_proto2" rule test { condition: test_proto2.requires_foo_and_bar }
-  |                                                         ^^^^^^^^^^^^^^^^^^^^ this field was used without foo
-  |`)
+  |                                                         ^^^^^^^^^^^^^^^^^^^^ this field was used without foo`)
 
 	_, err = Compile(rules, WithFeature("foo"))
 	assert.EqualError(t, err, `error[E100]: bar is required
  --> line:1:57
   |
 1 | import "test_proto2" rule test { condition: test_proto2.requires_foo_and_bar }
-  |                                                         ^^^^^^^^^^^^^^^^^^^^ this field was used without bar
-  |`)
+  |                                                         ^^^^^^^^^^^^^^^^^^^^ this field was used without bar`)
 
 	_, err = Compile(rules, WithFeature("foo"), WithFeature("bar"))
 	assert.NoError(t, err)
@@ -249,8 +260,7 @@ func TestErrors(t *testing.T) {
  --> test.yar:1:26
   |
 1 | rule test_2 { condition: foo }
-  |                          ^^^ this identifier has not been declared
-  |`,
+  |                          ^^^ this identifier has not been declared`,
 		},
 	}, c.Errors())
 }
@@ -354,8 +364,7 @@ func TestWarnings(t *testing.T) {
  --> line:1:31
   |
 1 | rule test { strings: $a = {01 [0-1][0-1] 02 } condition: $a }
-  |                               ---------- these consecutive jumps will be treated as [0-2]
-  |`,
+  |                               ---------- these consecutive jumps will be treated as [0-2]`,
 		},
 		{
 			Code:   "slow_pattern",
@@ -377,8 +386,7 @@ func TestWarnings(t *testing.T) {
  --> line:1:22
   |
 1 | rule test { strings: $a = {01 [0-1][0-1] 02 } condition: $a }
-  |                      ---------------------- this pattern may slow down the scan
-  |`,
+  |                      ---------------------- this pattern may slow down the scan`,
 		},
 	}, c.Warnings())
 }
