@@ -50,7 +50,9 @@ pub struct EmitWasmError(#[from] anyhow::Error);
 #[derive(Serialize)]
 #[serde(tag = "type")]
 pub enum CompileError {
+    ArbitraryRegexpPrefix(Box<ArbitraryRegexpPrefix>),
     AssignmentMismatch(Box<AssignmentMismatch>),
+    CircularIncludes(Box<CircularIncludes>),
     ConflictingRuleIdentifier(Box<ConflictingRuleIdentifier>),
     CustomError(Box<CustomError>),
     DuplicateModifier(Box<DuplicateModifier>),
@@ -197,7 +199,7 @@ pub struct SyntaxError {
     "expression should be {expected_types}, but it is {actual_type}",
     error_loc
 )]
-#[footer(help, Level::Help)]
+#[footer(help, Level::HELP)]
 pub struct WrongType {
     report: Report,
     expected_types: String,
@@ -334,12 +336,12 @@ pub struct InvalidRange {
 #[label(
     "duplicate declaration of `{new_rule}`",
     duplicate_rule_loc,
-    Level::Error
+    Level::ERROR
 )]
 #[label(
     "`{new_rule}` declared here for the first time",
     existing_rule_loc,
-    Level::Note
+    Level::NOTE
 )]
 pub struct DuplicateRule {
     report: Report,
@@ -413,7 +415,7 @@ pub struct EmptyPatternSet {
 #[label(
     "use `pe.entry_point` or `elf.entry_point` or `macho.entry_point`",
     error_loc,
-    Level::Help
+    Level::HELP
 )]
 pub struct EntrypointUnsupported {
     report: Report,
@@ -491,7 +493,7 @@ pub struct UnusedPattern {
 #[label(
     "`{pattern_ident}` declared here for the first time",
     note_loc,
-    Level::Note
+    Level::NOTE
 )]
 pub struct DuplicatePattern {
     report: Report,
@@ -894,6 +896,43 @@ pub struct IncludeNotAllowed {
     include_loc: CodeLoc,
 }
 
+/// Indicates that a regular expression has a prefix that can be arbitrarily
+/// long and matches any sequence of bytes.
+///
+/// # Example
+///
+/// error[E045]: arbitrary regular expression prefix  
+///  --> line:3:11  
+///   |  
+/// 3 |     $a = /.*foo/s  
+///   |           ^^ this prefix can be arbitrarily long and matches all bytes  
+///   |  
+///
+/// Regular expressions with such prefixes are problematic because YARA will
+/// report a match at every file offset from the start of the file up to where
+/// the rest of the pattern matches. In most cases, this prefix can be removed
+/// without affecting the rule's semantics.
+#[derive(ErrorStruct, Clone, Debug, PartialEq, Eq)]
+#[associated_enum(CompileError)]
+#[error(code = "E045", title = "arbitrary regular expression prefix")]
+#[label("this prefix can be arbitrarily long and matches all bytes", error_loc)]
+pub struct ArbitraryRegexpPrefix {
+    report: Report,
+    error_loc: CodeLoc,
+}
+
+/// Include statements have circular dependencies.
+#[derive(ErrorStruct, Clone, Debug, PartialEq, Eq)]
+#[associated_enum(CompileError)]
+#[error(code = "E046", title = "circular include dependencies")]
+#[label("include statement has circular dependencies", error_loc)]
+#[footer(note)]
+pub struct CircularIncludes {
+    report: Report,
+    error_loc: CodeLoc,
+    note: Option<String>,
+}
+
 /// A custom error has occurred.
 #[derive(ErrorStruct, Clone, Debug, PartialEq, Eq)]
 #[associated_enum(CompileError)]
