@@ -14,11 +14,12 @@ use yara_x_parser::Span;
 
 use crate::compiler::context::VarStack;
 use crate::compiler::errors::{
-    AssignmentMismatch, DuplicateModifier, DuplicatePattern, EmptyPatternSet,
-    EntrypointUnsupported, InvalidBase64Alphabet, InvalidModifier,
-    InvalidModifierCombination, InvalidPattern, InvalidRange, InvalidRegexp,
-    MismatchingTypes, MixedGreediness, NumberOutOfRange, SyntaxError,
-    TooManyPatterns, UnexpectedNegativeNumber, WrongArguments, WrongType,
+    ArbitraryRegexpPrefix, AssignmentMismatch, DuplicateModifier,
+    DuplicatePattern, EmptyPatternSet, EntrypointUnsupported,
+    InvalidBase64Alphabet, InvalidModifier, InvalidModifierCombination,
+    InvalidPattern, InvalidRange, InvalidRegexp, MismatchingTypes,
+    MixedGreediness, NumberOutOfRange, SyntaxError, TooManyPatterns,
+    UnexpectedNegativeNumber, WrongArguments, WrongType,
 };
 use crate::compiler::ir::hex2hir::hex_pattern_hir_from_ast;
 use crate::compiler::ir::{
@@ -165,8 +166,7 @@ pub(in crate::compiler) fn text_pattern_from_ast<'src>(
                 return Err(InvalidRange::build(
                     ctx.report_builder,
                     format!(
-                        "lower bound ({}) is greater than upper bound ({})",
-                        start, end
+                        "lower bound ({start}) is greater than upper bound ({end})"
                     ),
                     ctx.report_builder.span_to_code_loc(modifier.span()),
                 ));
@@ -290,7 +290,7 @@ pub(in crate::compiler) fn hex_pattern_from_ast<'src>(
             ctx.warnings.add(|| {
                 TextPatternAsHex::build(
                     ctx.report_builder,
-                    literal.escape_default().to_string(),
+                    escape(literal),
                     ctx.report_builder.span_to_code_loc(pattern.span()),
                 )
             });
@@ -309,6 +309,21 @@ pub(in crate::compiler) fn hex_pattern_from_ast<'src>(
     })
 }
 
+fn escape(s: &str) -> String {
+    let mut escaped = String::with_capacity(s.len());
+    for c in s.chars() {
+        match c {
+            '\r' => escaped.push_str("\\r"),
+            '\n' => escaped.push_str("\\n"),
+            '\t' => escaped.push_str("\\t"),
+            '\\' => escaped.push_str("\\\\"),
+            '"' => escaped.push_str("\\\""),
+            _ => escaped.push(c),
+        }
+    }
+    escaped
+}
+
 pub(in crate::compiler) fn regexp_pattern_from_ast<'src>(
     ctx: &mut CompileContext,
     pattern: &ast::RegexpPattern<'src>,
@@ -875,7 +890,7 @@ fn expr_from_ast(
                         ctx.report_builder
                             .span_to_code_loc(expr.primary.span()),
                         None,
-                    ))
+                    ));
                 }
             }
         }
@@ -957,7 +972,7 @@ fn bool_expr_from_ast(
                 "a map".to_string(),
                 code_loc,
                 None,
-            ))
+            ));
         }
         TypeValue::Struct(_) => {
             return Err(WrongType::build(
@@ -966,7 +981,7 @@ fn bool_expr_from_ast(
                 "a struct".to_string(),
                 code_loc,
                 None,
-            ))
+            ));
         }
         TypeValue::Array(_) => {
             return Err(WrongType::build(
@@ -975,7 +990,7 @@ fn bool_expr_from_ast(
                 "an array".to_string(),
                 code_loc,
                 None,
-            ))
+            ));
         }
         TypeValue::Regexp(_) => {
             return Err(WrongType::build(
@@ -984,7 +999,7 @@ fn bool_expr_from_ast(
                 "a regexp".to_string(),
                 code_loc,
                 None,
-            ))
+            ));
         }
         type_value => {
             warn_if_not_bool(ctx, type_value.ty(), ast.span());
@@ -1493,8 +1508,7 @@ fn range_from_ast(
             return Err(InvalidRange::build(
                 ctx.report_builder,
                 format!(
-                    "lower bound ({}) is greater than upper bound ({})",
-                    lower_bound, upper_bound
+                    "lower bound ({lower_bound}) is greater than upper bound ({upper_bound})"
                 ),
                 ctx.report_builder.span_to_code_loc(range.span()),
             ));
@@ -1605,7 +1619,7 @@ fn pattern_set_from_ast(
             pattern_indexes
         }
         // `x of ($a*, $b)`
-        ast::PatternSet::Set(ref set) => {
+        ast::PatternSet::Set(set) => {
             for item in set {
                 if !ctx
                     .current_rule_patterns
@@ -1673,7 +1687,7 @@ fn func_call_from_ast(
                 ctx.report_builder
                     .span_to_code_loc(func_call.identifier.span()),
                 None,
-            ))
+            ));
         }
     };
 
@@ -1777,7 +1791,7 @@ fn check_type(
         Err(WrongType::build(
             ctx.report_builder,
             CompileError::join_with_or(accepted_types, true),
-            format!("`{}`", ty),
+            format!("`{ty}`"),
             ctx.report_builder.span_to_code_loc(span),
             None,
         ))
@@ -1833,7 +1847,7 @@ fn re_error_to_compile_error(
     err: re::parser::Error,
 ) -> CompileError {
     match err {
-        re::parser::Error::SyntaxError { msg, span, note } => {
+        re::parser::Error::WrongSyntax { msg, span, note } => {
             InvalidRegexp::build(
                 report_builder,
                 msg,
@@ -1855,6 +1869,17 @@ fn re_error_to_compile_error(
                 note,
             )
         }
+        re::parser::Error::ArbitraryPrefix { span } => {
+            ArbitraryRegexpPrefix::build(
+                report_builder,
+                report_builder.span_to_code_loc(
+                    regexp
+                        .span()
+                        .subspan(span.start.offset, span.end.offset)
+                        .offset(1),
+                ),
+            )
+        }
         re::parser::Error::MixedGreediness {
             is_greedy_1,
             is_greedy_2,
@@ -2332,7 +2357,7 @@ fn eq_check(
                         ctx.warnings.add(|| {
                             UnsatisfiableExpression::build(
                                 ctx.report_builder,
-                                format!("the length of this string is {}", n),
+                                format!("the length of this string is {n}"),
                                 format!(
                                     "the length of this string is {}",
                                     const_string.len()
