@@ -27,9 +27,25 @@ fn log_msg_str(
     true
 }
 
+#[module_export(name = "log")]
+fn log_bool(ctx: &mut ScanContext, b: bool) -> bool {
+    ctx.console_log(format!("{b}"));
+    true
+}
+
+#[module_export(name = "log")]
+fn log_msg_bool(
+    ctx: &mut ScanContext,
+    message: RuntimeString,
+    b: bool,
+) -> bool {
+    ctx.console_log(format!("{}{}", message.as_bstr(ctx), b));
+    true
+}
+
 #[module_export(name = "log")]
 fn log_int(ctx: &mut ScanContext, i: i64) -> bool {
-    ctx.console_log(format!("{}", i));
+    ctx.console_log(format!("{i}"));
     true
 }
 
@@ -41,7 +57,7 @@ fn log_msg_int(ctx: &mut ScanContext, message: RuntimeString, i: i64) -> bool {
 
 #[module_export(name = "log")]
 fn log_float(ctx: &mut ScanContext, f: f64) -> bool {
-    ctx.console_log(format!("{}", f));
+    ctx.console_log(format!("{f}"));
     true
 }
 
@@ -57,7 +73,7 @@ fn log_msg_float(
 
 #[module_export(name = "hex")]
 fn log_hex(ctx: &mut ScanContext, i: i64) -> bool {
-    ctx.console_log(format!("0x{:x}", i));
+    ctx.console_log(format!("0x{i:x}"));
     true
 }
 
@@ -82,8 +98,11 @@ mod tests {
                     console.log("baz: ", 3.14) and
                     console.log(10) and
                     console.log(6.28) and
+                    console.log(true) and
+                    console.log("bool: ", true) and
                     console.hex(10) and
-                    console.hex("qux: ", 255)
+                    console.hex("qux: ", 255) and
+                    console.log("hello ", "world!")
             }
             "#,
         )
@@ -104,8 +123,11 @@ mod tests {
                 "baz: 3.14",
                 "10",
                 "6.28",
+                "true",
+                "bool: true",
                 "0xa",
-                "qux: 0xff"
+                "qux: 0xff",
+                "hello world!",
             ]
         );
     }
