@@ -27,10 +27,14 @@ thread_local!(
 );
 
 #[module_main]
-fn main(data: &[u8], _meta: Option<&[u8]>) -> ELF {
+fn main(data: &[u8], _meta: Option<&[u8]>) -> Result<ELF, ModuleError> {
     IMPORT_MD5_CACHE.with(|cache| *cache.borrow_mut() = None);
     TLSH_CACHE.with(|cache| *cache.borrow_mut() = None);
-    parser::ElfParser::new().parse(data).unwrap_or_else(|_| ELF::new())
+
+    match parser::ElfParser::new().parse(data) {
+        Ok(elf) => Ok(elf),
+        Err(_) => Ok(ELF::new()),
+    }
 }
 
 #[module_export]
