@@ -10,7 +10,6 @@ use std::ops::Deref;
 use std::path::{Path, PathBuf};
 use std::pin::Pin;
 use std::ptr::{null, NonNull};
-use std::rc::Rc;
 use std::slice::Iter;
 use std::sync::atomic::{AtomicU64, Ordering};
 use std::sync::Once;
@@ -171,6 +170,7 @@ pub struct Scanner<'r> {
     wasm_main_func: TypedFunc<(), i32>,
     filesize: Global,
     timeout: Option<Duration>,
+    use_mmap: bool,
 }
 
 impl<'r> Scanner<'r> {
@@ -323,7 +323,14 @@ impl<'r> Scanner<'r> {
 
         wasm_store.data_mut().main_memory = Some(main_memory);
 
-        Self { rules, wasm_store, wasm_main_func, filesize, timeout: None }
+        Self {
+            rules,
+            wasm_store,
+            wasm_main_func,
+            filesize,
+            timeout: None,
+            use_mmap: true,
+        }
     }
 
     /// Sets a timeout for scan operations.
@@ -348,6 +355,22 @@ impl<'r> Scanner<'r> {
         self
     }
 
+    /// Specifies whether [`Scanner::scan_file`] and [`Scanner::scan_file_with_option`]
+    /// may use memory-mapped files to read input.
+    ///
+    /// By default, the scanner uses memory mapping for very large files, as this
+    /// is typically faster than copying file contents into memory. However, this
+    /// approach has a drawback: if another process truncates the file during
+    /// scanning, a `SIGBUS` signal may occur.
+    ///
+    /// Setting this option disables memory mapping and forces the scanner to
+    /// always read files into an in-memory buffer instead. This method is slower,
+    /// but safer.
+    pub fn use_mmap(&mut self, yes: bool) -> &mut Self {
+        self.use_mmap = yes;
+        self
+    }
+
     /// Sets a callback that is invoked every time a YARA rule calls the
     /// `console` module.
     ///
@@ -379,7 +402,7 @@ impl<'r> Scanner<'r> {
     where
         P: AsRef<Path>,
     {
-        self.scan_impl(Self::load_file(target.as_ref())?, None)
+        self.scan_impl(self.load_file(target.as_ref())?, None)
     }
 
     /// Like [`Scanner::scan`], but allows to specify additional scan options.
@@ -401,7 +424,7 @@ impl<'r> Scanner<'r> {
     where
         P: AsRef<Path>,
     {
-        self.scan_impl(Self::load_file(target.as_ref())?, Some(options))
+        self.scan_impl(self.load_file(target.as_ref())?, Some(options))
     }
 
     /// Sets the value of a global variable.
@@ -553,7 +576,7 @@ impl<'r> Scanner<'r> {
     /// performance bottlenecks. To reset the profiling data and start fresh
     /// for subsequent scans, use [`Scanner::clear_profiling_data`].
     #[cfg(feature = "rules-profiling")]
-    pub fn slowest_rules(&self, n: usize) -> Vec<ProfilingData> {
+    pub fn slowest_rules(&self, n: usize) -> Vec<ProfilingData<'_>> {
         self.scan_context().slowest_rules(n)
     }
 
@@ -586,7 +609,10 @@ impl<'r> Scanner<'r> {
         }
     }
 
-    fn load_file(path: &Path) -> Result<ScannedData<'static>, ScanError> {
+    fn load_file(
+        &self,
+        path: &Path,
+    ) -> Result<ScannedData<'static>, ScanError> {
         let mut file = fs::File::open(path).map_err(|err| {
             ScanError::OpenError { path: path.to_path_buf(), err }
         })?;
@@ -598,19 +624,19 @@ impl<'r> Scanner<'r> {
 
         // For files smaller than ~500MB reading the whole file is faster than
         // using a memory-mapped file.
-        let data = if size < 500_000_000 {
-            buffered_file = Vec::with_capacity(size as usize);
-            file.read_to_end(&mut buffered_file).map_err(|err| {
-                ScanError::OpenError { path: path.to_path_buf(), err }
-            })?;
-            ScannedData::Vec(buffered_file)
-        } else {
+        let data = if self.use_mmap && size > 500_000_000 {
             mapped_file = unsafe {
                 MmapOptions::new().map_copy_read_only(&file).map_err(|err| {
                     ScanError::MapError { path: path.to_path_buf(), err }
                 })
             }?;
             ScannedData::Mmap(mapped_file)
+        } else {
+            buffered_file = Vec::with_capacity(size as usize);
+            file.read_to_end(&mut buffered_file).map_err(|err| {
+                ScanError::OpenError { path: path.to_path_buf(), err }
+            })?;
+            ScannedData::Vec(buffered_file)
         };
 
         Ok(data)
@@ -688,10 +714,9 @@ impl<'r> Scanner<'r> {
 
         for module_name in ctx.compiled_rules.imports() {
             // Lookup the module in the list of built-in modules.
-            let module =
-                modules::BUILTIN_MODULES.get(module_name).unwrap_or_else(
-                    || panic!("module `{}` not found", module_name),
-                );
+            let module = modules::BUILTIN_MODULES
+                .get(module_name)
+                .unwrap_or_else(|| panic!("module `{module_name}` not found"));
 
             let root_struct_name = module.root_struct_descriptor.full_name();
 
@@ -775,10 +800,8 @@ impl<'r> Scanner<'r> {
             // The data structure obtained from the module is added to the
             // root structure. Any data from previous scans will be replaced
             // with the new data structure.
-            ctx.root_struct.add_field(
-                module_name,
-                TypeValue::Struct(Rc::new(module_struct)),
-            );
+            ctx.root_struct
+                .add_field(module_name, TypeValue::Struct(module_struct));
         }
 
         // Save the time in which the evaluation of rules started.
@@ -866,13 +889,12 @@ impl<'r> Scanner<'r> {
 
         match func_result {
             Ok(0) => Ok(ScanResults::new(self.scan_context(), data)),
-            Ok(v) => panic!("WASM main returned: {}", v),
+            Ok(v) => panic!("WASM main returned: {v}"),
             Err(err) if err.is::<ScanError>() => {
                 Err(err.downcast::<ScanError>().unwrap())
             }
             Err(err) => panic!(
-                "unexpected error while executing WASM main function: {}",
-                err
+                "unexpected error while executing WASM main function: {err}"
             ),
         }
     }
