@@ -35,6 +35,9 @@ pub(crate) enum Symbol {
         type_value: TypeValue,
         /// Access control list (ACL) for accessing this field.
         acl: Option<Vec<AclEntry>>,
+        /// If the field is deprecated, this will contain the message shown when
+        /// the field is used in a rule.
+        deprecation_msg: Option<String>,
     },
     /// The symbol refers to a rule.
     Rule(RuleId),
@@ -126,7 +129,7 @@ impl Symbol {
 
     #[cfg(test)]
     fn as_integer(&self) -> Option<i64> {
-        if let TypeValue::Integer { value } = self.type_value() {
+        if let TypeValue::Integer { value, .. } = self.type_value() {
             value.extract().cloned()
         } else {
             None
