@@ -217,7 +217,7 @@ impl Debug for CST {
         if !self.errors.is_empty() {
             writeln!(f, "\nERRORS:")?;
             for (span, err) in &self.errors {
-                writeln!(f, "- {}: {}", span, err)?;
+                writeln!(f, "- {span}: {err}")?;
             }
         }
         Ok(())
@@ -872,6 +872,57 @@ impl<M> Node<M> {
         // real siblings.
         self.inner.siblings_with_tokens(direction).skip(1).map(|x| x.into())
     }
+
+    /// Returns the token at a given offset within the source code.
+    ///
+    /// If the offset points code that is outside the current node, this
+    /// function returns `None`.
+    ///
+    ///
+    /// ```rust
+    /// # use yara_x_parser::cst::SyntaxKind;
+    /// use yara_x_parser::Parser;
+    /// let mut root_node = Parser::new(b"rule test {condition:true}")
+    ///     .try_into_cst()
+    ///     .unwrap()
+    ///     .root();
+    ///
+    /// let rule_decl = root_node.first_child().unwrap();
+    ///
+    /// // Should find `SyntaxKind::RULE_KW` token at offset 0.
+    /// assert_eq!(
+    ///     rule_decl.token_at_offset(0).unwrap().kind(),
+    ///     SyntaxKind::RULE_KW);
+    ///
+    /// // Should find `SyntaxKind::WHITESPACE` token at offset 4.
+    /// assert_eq!(
+    ///     rule_decl.token_at_offset(4).unwrap().kind(),
+    ///     SyntaxKind::WHITESPACE);
+    ///
+    /// let condition_blk = rule_decl.first_child().unwrap();
+    ///
+    /// // When calling `token_at_offset(0)` on the node that represents
+    /// // the condition block the result is `None` because the `rule`
+    /// // keyword is not contained in that node.
+    /// assert!(condition_blk.token_at_offset(0).is_none());
+    ///
+    /// // Should return `None` for an empty file.
+    /// let mut empty = Parser::new(b"")
+    ///     .try_into_cst()
+    ///     .unwrap()
+    ///     .root();
+    ///
+    /// assert!(empty.token_at_offset(0).is_none());
+    /// ```
+    pub fn token_at_offset(&self, offset: usize) -> Option<Token<M>> {
+        if !self.span().range().contains(&offset) {
+            return None;
+        }
+        self.inner
+            .token_at_offset(offset.try_into().ok()?)
+            .right_biased()
+            .map(Token::new)
+    }
 }
 
 impl Node<Immutable> {
